[jhbuild] build: Use new documentation infraestructure



commit 6fdaf504a3977d0abc1541180c673eb48f6cf528
Author: Javier JardÃn <jjardon gnome org>
Date:   Fri Jan 20 19:51:59 2012 +0100

    build: Use new documentation infraestructure

 .gitignore                           |    4 ----
 Makefile.am                          |    2 +-
 README                               |    5 +----
 autogen.sh                           |   32 +++++++++++---------------------
 configure.ac                         |    5 ++---
 doc/C/{jhbuild.xml => index.docbook} |    6 +++---
 doc/Makefile.am                      |   11 ++++++-----
 doc/jhbuild.omf.in                   |    9 ---------
 8 files changed, 24 insertions(+), 50 deletions(-)
---
diff --git a/.gitignore b/.gitignore
index 061e7e1..7fde771 100644
--- a/.gitignore
+++ b/.gitignore
@@ -19,8 +19,6 @@ mo/
 /configure
 /depcomp
 /doc/*/.xml2po.mo
-/doc/*/jhbuild.xml
-/doc/jhbuild-*.omf
 /examples/jhbuild.desktop
 /gnome-doc-utils.make
 /install-check
@@ -35,7 +33,6 @@ mo/
 /m4/
 /missing
 /mkinstalldirs
-/omf.make
 /po/*.gmo
 /po/.intltool-merge-cache
 /po/Makefile.in.in
@@ -61,7 +58,6 @@ mo/
 /tests/*/depcomp
 /tests/*/install-sh
 /tests/*/missing
-/tests/*/omf.make
 /tests/*/xmldocs.make
 /tests/autotools/hello
 /tests/distutils/build/
diff --git a/Makefile.am b/Makefile.am
index cc99512..78d622d 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -20,7 +20,7 @@ INTLTOOL = 			\
 	intltool-merge.in 	\
 	intltool-update.in
 
-EXTRA_DIST = gnome-doc-utils.make $(PATCHES) $(MODULESETS) \
+EXTRA_DIST = $(PATCHES) $(MODULESETS) \
 	install-check.c \
 	autogen.sh \
 	$(desktop_in_files) $(INTLTOOL)
diff --git a/README b/README
index ed19489..36faa4b 100644
--- a/README
+++ b/README
@@ -14,10 +14,7 @@ Installing JHBuild
 
 Refer to the 'Getting Started' section of the JHBuild manual:
 
-  gnome-help ghelp:/jhbuild-source-dir/doc/C/jhbuild.xml
-
-where 'jhbuild-source-dir' is the full path to the JHBuild source
-directory.
+  yelp /jhbuild-source-dir/doc/C/index.docbook
 
 Or refer to the on-line JHBuild manual at:
 
diff --git a/configure.ac b/configure.ac
index 0518027..b4fb0fe 100644
--- a/configure.ac
+++ b/configure.ac
@@ -33,9 +33,8 @@ AC_ARG_ENABLE(
 	[enable_doc_installation=$enableval],
 	[enable_doc_installation=no])
 AM_CONDITIONAL([DOC_INSTALLATION_ENABLED],[test "x$enable_doc_installation" = "xyes"])
-# pkg-config check below is disabled since documentation is optional
-# PKG_CHECK_MODULES(gnome-doc-utils, gnome-doc-utils)
-GNOME_DOC_INIT
+
+YELP_HELP_INIT
 
 AC_CONFIG_FILES([
 	Makefile
diff --git a/doc/C/jhbuild.xml b/doc/C/index.docbook
similarity index 99%
rename from doc/C/jhbuild.xml
rename to doc/C/index.docbook
index 220909f..ee19a8d 100644
--- a/doc/C/jhbuild.xml
+++ b/doc/C/index.docbook
@@ -1,7 +1,7 @@
 <?xml version="1.0" standalone="no"?><!--*- mode: nxml -*-->
 <!DOCTYPE article PUBLIC "-//OASIS//DTD DocBook XML V4.2//EN"
     "http://www.oasis-open.org/docbook/xml/4.2/docbookx.dtd";>
-<!-- process to HTML with: xmlto xhtml-nochunks -m ../custom.xsl jhbuild.xml -->
+<!-- process to HTML with: xmlto xhtml-nochunks -m ../custom.xsl index.docbook -->
 <article id="index">
   <articleinfo>
     <title>JHBuild Manual</title>
@@ -115,12 +115,12 @@
 <prompt>$</prompt></screen>
 
       <para>If <application>gnome-common</application>,
-        <application>gnome-doc-utils</application> and
+        <application>yelp-tools</application> and
         <application>autotools</application> are available,
         <filename>autogen.sh</filename> will configure JHBuild to install via
         <application>autotools</application>. If
         <application>gnome-common</application>,
-        <application>gnome-doc-utils</application> and
+        <application>yelp-tools</application> and
         <application>autotools</application> are not available,
         <filename>autogen.sh</filename> will configure JHBuild to install via a
         plain Makefile. To always use the plain Makefile method pass
diff --git a/doc/Makefile.am b/doc/Makefile.am
index 514b4c2..138df15 100644
--- a/doc/Makefile.am
+++ b/doc/Makefile.am
@@ -1,8 +1,9 @@
-include $(top_srcdir)/build-aux/gnome-doc-utils.make
+ YELP_HELP_RULES@
 
-DOC_LINGUAS = de el es fr ja sl sv
+HELP_ID = jhbuild
 
-dist-hook: doc-dist-hook
+HELP_LINGUAS = de el es fr ja sl sv
 
-DOC_MODULE = jhbuild
-DOC_FIGURES = figures/jhbuild_sample_dot_output.png
+HELP_FILES = index.docbook
+
+HELP_MEDIA = figures/jhbuild_sample_dot_output.png



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/autogen.sh b/autogen.sh
index 478dd85..78304ef 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -3,8 +3,7 @@
 # JHBuild configuration script.
 #
 # For installation instructions please refer to the JHBuild manual:
-#   gnome-help ghelp:/jhbuild-source-dir/doc/C/jhbuild.xml
-# where 'jhbuild-source-dir' is the full path to the JHBuild source directory.
+#   yelp /jhbuild-source-dir/doc/C/index.docbook
 #
 # Or refer to the on-line JHBuild manual at:
 #
@@ -14,14 +13,14 @@
 # ./autogen.sh [OPTION]
 #    Available OPTION are:
 #      --simple-install   Configure without using autotools. This setting is
 #                         set automatically if gnome-common and gnome-doc-utils
 #                         are not installed.
 #      --prefix=PREFIX    Install JHBuild to PREFIX. Defaults to ~/.local
 #
 # If gnome-common and gnome-doc-utils are available, this configuration script
 # will configure JHBuild to install via autotools.
 #
 # If gnome-common and gnome-doc-utils are not available, this configuration
 # script will configure JHBuild to install via a plain Makefile.
 #
 # autogen.sh is used to configure JHBuild because the most common way to obtain
@@ -154,7 +153,7 @@ configure_with_autotools()
   REQUIRED_AUTOMAKE_VERSION=1.8 \
   REQUIRED_INTLTOOL_VERSION=0.35.0 \
   REQUIRED_PKG_CONFIG_VERSION=0.16.0 \
-  USE_COMMON_DOC_BUILD=yes gnome-autogen.sh $@
+  gnome-autogen.sh $@
 }
 
 # Check for make. make is required to provide i18n for this script and to
@@ -189,31 +188,22 @@ fi
 hash gnome-autogen.sh 2>&-
 gnome_autogen_available=$?
 
-# Check gnome-doc-tool is installed.
-hash gnome-doc-tool 2>&-
-gnome_doc_tool_available=$?
-
-# Check gnome-doc-prepare is installed.
-hash gnome-doc-prepare 2>&-
-gnome_doc_prepare_available=$?
+# Check yelp-tools is installed.
+hash yelp-build 2>&-
+yelp_tools_available=$?
 
 parse_commandline $*
 
 if [ $gnome_autogen_available -eq 0 -a \
-     $gnome_doc_tool_available -eq 0 -a \
-     $gnome_doc_prepare_available -eq 0 -a \
+     $yelp_tools_available -eq 0 -a \
      $enable_autotools -eq 1 ]; then
   configure_with_autotools $*
 else
   if [ $gnome_autogen_available -ne 0 ]; then
     gettext "gnome-autogen.sh not available"; echo
   fi
-  if [ $gnome_doc_tool_available -ne 0 ]; then
-    gettext "gnome-doc-tool not available"; echo
-  elif [ $gnome_doc_prepare_available -ne 0 ]; then
-    # OpenSuSe splits gnome-doc-prepare into separate gnome-doc-utils-devel
-    # package
-    gettext "gnome-doc-prepare not available"; echo
+  if [ $yelp_tools_available -ne 0 ]; then
+    gettext "yelp-tools not available"; echo
   fi
   configure_without_autotools
 fi
@@ -14,14 +13,14 @@
 #    Available OPTION are:
 #      --simple-install   Configure without using autotools. This setting is
-#                         set automatically if gnome-common and gnome-doc-utils
+#                         set automatically if gnome-common and yelp-tools
 #                         are not installed.
 #      --prefix=PREFIX    Install JHBuild to PREFIX. Defaults to ~/.local
@@ -14,14 +13,14 @@
 #      --prefix=PREFIX    Install JHBuild to PREFIX. Defaults to ~/.local
 #
-# If gnome-common and gnome-doc-utils are available, this configuration script
+# If gnome-common and yelp-tools are available, this configuration script
 # will configure JHBuild to install via autotools.
 #
@@ -14,14 +13,14 @@
 # will configure JHBuild to install via autotools.
 #
-# If gnome-common and gnome-doc-utils are not available, this configuration
+# If gnome-common and yelp-tools are not available, this configuration
 # script will configure JHBuild to install via a plain Makefile.
 #